==> elgg-1.12.12.zip: elgg-1.12.12/mod/groups/languages/el.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ομάδες",
	'groups:owned' => "Ομάδες που μου ανήκουν",
	'groups:owned:user' => 'Ομάδες που ανήκουν στο χρήστη %s',
	'groups:yours' => "Οι ομάδες μου",
	'groups:user' => "Ομάδες του χρήστη %s",
	'groups:all' => "Όλες οι ομάδες",
	'groups:add' => "Δημιουργία ομάδας",
	'groups:edit' => "Επεξεργασία ομάδας",
	'groups:delete' => 'Διαγραφή ομάδας',
	'groups:membershiprequests' => 'Διαχείριση αιτημάτων σύνδεσης',
	'groups:membershiprequests:pending' => 'Διαχείριση αιτημάτων σύνδεσης (%s)',
	'groups:invitations' => 'Προσκλήσεις ομάδας',
	'groups:invitations:pending' => 'Προσκλήσεις ομάδας (%s)',

	'groups:icon' => 'Εικόνα ομάδας (αφήστε κενό για καμία αλλαγή)',
	'groups:name' => 'Όνομα ομάδας',
	'groups:username' => 'Σύντομο όνομα ομάδας (εμφανίζεται στη μπάρα διευθύνσεων, αλφαριθμητικοί χαρακτήρες μόνο)',
	'groups:description' => 'Περιγραφή',
	'groups:briefdescription' => 'Σύντομη περιγραφή',
	'groups:interests' => 'Ετικέτες',
	'groups:website' => 'Ιστότοπος',
	'groups:members' => 'Μέλη ομάδας',
	'groups:my_status' => 'Κατάσταση',
	'groups:my_status:group_owner' => 'Αυτή η ομάδα σας ανήκει',
	'groups:my_status:group_member' => 'Είστε μέλος αυτής της ομάδας',
	'groups:subscribed' => 'Ειδοποιήσεις ομάδας: ενεργό',
	'groups:unsubscribed' => 'Ειδοποιήσεις ομάδας: μη ενεργό',

	'groups:members:title' => 'Μέλη ομάδας %s',
	'groups:members:more' => "Προβολή όλων των μελών",
	'groups:membership' => "Δικαιώματα μελών ομάδας",
	'groups:content_access_mode' => "Προσβασιμότητα του περιεχομένου της ομάδας",
	'groups:content_access_mode:warning' => "Προσοχή: Η αλλαγή αυτής της ρύθμισης δεν θα επηρεάσει τα δικαιώματα πρόσβασης στο υφιστάμενο περιεχόμενο της ομάδας.",
	'groups:content_access_mode:unrestricted' => "Χωρίς περιορισμό - Η πρόσβαση εξαρτάται από τις ρυθμίσεις σε επίπεδο περιεχομένου",
	'groups:content_access_mode:membersonly' => "Μόνο για Μέλη  - Μη μέλη δεν μπορούν να έχουν πρόσβαση στο περιεχόμενο της ομάδας",
	'groups:access' => "Δικαιώματα πρόσβασης",
	'groups:owner' => "Ιδιοκτήτης",
	'groups:owner:warning' => "Προσοχή: εάν αλλάξετε την τιμή αυτή, δεν θα είστε πλέον ο ιδιοκτήτης αυτής της ομάδας.",
	'groups:widget:num_display' => 'Αριθμός ομάδων για εμφάνιση',
	'groups:widget:membership' => 'Συμμετοχή στην ομάδα',
	'groups:widgets:description' => 'Εμφάνιση στο προφίλ σας των ομάδων που είστε μέλος ',

	'groups:widget:group_activity:title' => 'Δραστηριότητα ομάδας',
	'groups:widget:group_activity:description' => 'Δείτε τη δραστηριότητα σε μία από τις ομάδες σας',
	'groups:widget:group_activity:edit:select' => 'Επιλέξτε μία ομάδα',
	'groups:widget:group_activity:content:noactivity' => 'Δεν υπάρχει δραστηριότητα στην ομάδα',
	'groups:widget:group_activity:content:noselect' => 'Επεξεργαστείτε αυτό το widget για να επιλέξετε μια ομάδα',

	'groups:noaccess' => 'Δεν παρέχεται πρόσβαση στην ομάδα',
	'groups:permissions:error' => 'Δεν έχετε δικαιώματα σε αυτό',
	'groups:ingroup' => 'στην ομάδα',
	'groups:cantcreate' => 'Δεν μπορείτε να δημιουργήσετε ομάδα. Μόνο οι διαχειριστές μπορούν.',
	'groups:cantedit' => 'Δεν μπορείτε να επεξεργαστείτε αυτή την ομάδα',
	'groups:saved' => 'Η ομάδα αποθηκεύτηκε',
	'groups:save_error' => 'Group could not be saved',
	'groups:featured' => 'Προβεβλημένες ομάδες',
	'groups:makeunfeatured' => 'Μη προτεινόμενο',
	'groups:makefeatured' => 'Προβάλλετε το',
	'groups:featuredon' => '%s είναι πλέον προβεβλημένη ομάδα.',
	'groups:unfeatured' => 'Η ομάδα %s έχει διαγραφεί πλέον από τις προβεβλημένες ομάδες.',
	'groups:featured_error' => 'Μη έγκυρη ομάδα.',
	'groups:nofeatured' => 'Μη προβεβλημένες ομάδες',
	'groups:joinrequest' => 'Αίτημα εγγραφής',
	'groups:join' => 'Συμμετοχή στην ομάδα',
	'groups:leave' => 'Εγκατάλλειψη ομάδας',
	'groups:invite' => 'Πρόσκληση φίλων',
	'groups:invite:title' => 'Πρόσκληση φίλων σ\' αυτή την ομάδα',
	'groups:inviteto' => "Πρόσκληση φίλων στην ομάδα  '%s'",
	'groups:nofriends' => "Δεν υπάρχουν φίλοι σας που δεν έχουν προσκληθεί σε αυτήν την ομάδα.",
	'groups:nofriendsatall' => 'Δεν έχετε φίλους για να προσκαλέσετε',
	'groups:viagroups' => "μέσω ομάδων",
	'groups:group' => "Ομάδα",
	'groups:search:tags' => "ετικέτα",
	'groups:search:title' => "Αναζήτηση για ομάδες με ετικέτα '%s'",
	'groups:search:none' => "Δεν βρέθηκαν ομάδες",
	'groups:search_in_group' => "Αναζήτηση σ' αυτή την ομάδα",
	'groups:acl' => "Ομάδα: %s",

	'discussion:topic:notify:summary' => 'Νέο θέμα συζήτησης με ονομασία %s',
	'discussion:topic:notify:subject' => 'Νέο θέμα συζήτησης: %s',
	'discussion:topic:notify:body' =>
'Ο/η %s πρόσθεσε ένα νέο θέμα συζήτησης στην ομάδα %s:

Τίτλος: %s

%s

Δείτε και συμμετέχετε στη συζήτηση:
%s
',

	'discussion:reply:notify:summary' => 'Νέα απάντηση στη συζήτηση: %s',
	'discussion:reply:notify:subject' => 'Νέα απάντηση στη συζήτηση: %s ',
	'discussion:reply:notify:body' =>
'Ο/η %s απάντησε στη συζήτηση %s της ομάδας %s:

%s

Δείτε και συμμετέχετε στη συζήτηση:
%s
',

	'groups:activity' => "Δραστηριότητα ομάδας",
	'groups:enableactivity' => 'Ενεργοποίηση δραστηριότητας ομάδας',
	'groups:activity:none' => "Δεν υπάρχει ακόμα δραστηριότητα στην ομάδα",

	'groups:notfound' => "Η ομάδα δεν βρέθηκε",
	'groups:notfound:details' => "Η ζητούμενη ομάδα είτε δεν υπάρχει είτε δεν έχετε πρόσβαση σε αυτήν",

	'groups:requests:none' => 'Δεν υπάρχουν τρέχουσες αιτήσεις συμμετοχής.',

	'groups:invitations:none' => 'Δεν υπάρχουν τρέχουσες προσκλήσεις.',

	'item:object:groupforumtopic' => "Θέματα συζήτησης",
	'item:object:discussion_reply' => "Απαντήσεις συζητήσης",

	'groupforumtopic:new' => "Προσθήκη συζήτησης",

	'groups:count' => "ομάδες δημιουργήθηκαν",
	'groups:open' => "Ανοικτή ομάδα",
	'groups:closed' => "Κλειστή ομάδα",
	'groups:member' => "μέλη",
	'groups:searchtag' => "Αναζήτηση ομάδων με χρήση ετικέτας",

	'groups:more' => 'Περισσότερες ομάδες',
	'groups:none' => 'Δεν υπάρχουν ομάδες',

	/**
	 * Access
	 */
	'groups:access:private' => 'Κλειστό - Οι χρήστες πρέπει να προσκληθούν',
	'groups:access:public' => 'Ανοικτό - Όλοι οι χρήστες μπορούν να συνδεθούν',
	'groups:access:group' => 'Μόνο μέλη της ομάδας',
	'groups:closedgroup' => "Αυτή η ομάδα είναι κλειστή.",
	'groups:closedgroup:request' => 'Για να ζητήσετε τη συμμετοχής σας, κάντε κλικ στο "Αίτημα εγγραφής" στο μενού.',
	'groups:closedgroup:membersonly' => "Η ομάδα αυτή είναι κλειστή και το περιεχόμενό της είναι προσβάσιμο μόνο από τα μέλη.",
	'groups:opengroup:membersonly' => "Το περιεχόμενο της ομάδας της είναι προσβάσιμο μόνο από τα μέλη.",
	'groups:opengroup:membersonly:join' => 'Για να γίνετε μέλος, επιλέξτε "Συμμετοχή στην ομάδα" στο μενού.',
	'groups:visibility' => 'Ποιος μπορεί να δει αυτή την ομάδα?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Ενεργοποίηση συζητήσεων ομάδας',
	'groups:lastupdated' => 'Τελευταία ενημέρωση %s από %s',
	'groups:lastcomment' => 'Τελευταίο σχόλιο %s από %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Συζήτηση',
	'discussion:add' => 'Προσθήκη θέματος συζήτησης',
	'discussion:latest' => 'Τελευταία συζήτηση',
	'discussion:group' => 'Συζήτηση ομάδας',
	'discussion:none' => 'Δεν υπάρχουν συζητήσεις',
	'discussion:reply:title' => 'Απάντηση από %s',

	'discussion:topic:created' => 'Το νέο θέμα συζήτησης δημιουργήθηκε.',
	'discussion:topic:updated' => 'Το θέμα συζήτησης ενημερώθηκε.',
	'discussion:topic:deleted' => 'Το θέμα συζήτησης διαγράφτηκε.',

	'discussion:topic:notfound' => 'Δεν βρέθηκε το θέμα συζήτησης',
	'discussion:error:notsaved' => 'Δεν ήταν δυνατή η αποθήκευση του θέματος',
	'discussion:error:missing' => 'Ο τίτλος και το μήνυμα είναι υποχρεωτικά πεδία',
	'discussion:error:permissions' => 'Δεν έχετε δικαιώματα εκτέλεσης αυτής της ενέργειας',
	'discussion:error:notdeleted' => 'Δεν ήταν δυνατή η διαγραφή της συζήτησης',

	'discussion:reply:edit' => 'Επεξεργασία απάντησης',
	'discussion:reply:deleted' => 'Η απάντηση στη συζήτηση έχει διαγραφτεί',
	'discussion:reply:error:notfound' => 'Η απάντηση δεν βρέθηκε',
	'discussion:reply:error:notfound_fallback' => "Συγνώμη, δεν μπορέσαμε να βρούμε την συγκεκριμένη απάντηση. Έχετε προωθηθεί στην αρχική συζήτηση.",
	'discussion:reply:error:notdeleted' => 'Δεν ήταν δυνατή η διαγραφή της απάντησης της συζήτησης',

	'discussion:search:title' => 'Απάντηση στο θέμα: %s',
	
	'admin:groups' => 'Ομάδες',

	'reply:this' => 'Απάντηση',

	'group:replies' => 'Απαντήσεις',
	'groups:forum:created' => 'Δημιουργήθηκε %s με %d σχόλια',
	'groups:forum:created:single' => 'Δημιουργήθηκε %s με %d απάντηση',
	'groups:forum' => 'Συζήτηση',
	'groups:addtopic' => 'Προσθέστε ένα νέο θέμα',
	'groups:forumlatest' => 'Τελευταία συζήτηση',
	'groups:latestdiscussion' => 'Τελευταία συζήτηση',
	'groupspost:success' => 'Η απάντηση σας αναρτήθηκε με επιτυχία',
	'groupspost:failure' => 'Παρουσιάστηκε πρόβλημα κατά την ανάρτηση της απάντησης σας',
	'groups:alldiscussion' => 'Τελευταία συζήτηση',
	'groups:edittopic' => 'Επεξεργασία θέματος',
	'groups:topicmessage' => 'Μήνυμα θέματος',
	'groups:topicstatus' => 'Κατάσταση θέματος',
	'groups:reply' => 'Σχολιάστε',
	'groups:topic' => 'Θέμα',
	'groups:posts' => 'Αναρτήσεις',
	'groups:lastperson' => 'Τελευταίο άτομο',
	'groups:when' => 'Πότε',
	'grouptopic:notcreated' => 'Δεν υπάρχουν θέματα συζήτησης',
	'groups:topicclosed' => 'Κλειστό',
	'grouptopic:created' => 'Το θέμα σας δημιουργήθηκε.',
	'groups:topicsticky' => 'Sticky',
	'groups:topicisclosed' => 'Αυτή η συζήτηση έχει κλείσει.',
	'groups:topiccloseddesc' => 'Αυτή η συζήτηση έχει κλείσει και δεν επιτρέπονται νέα σχόλια',
	'grouptopic:error' => 'Δεν ήταν δυνατή η δημιουργία του θέματος της ομάδας σας. Παρακαλώ δοκιμάστε ξανά ή επικοινωνήστε με τον διαχειριστή του συστήματος.',
	'groups:forumpost:edited' => "Έχετε επεξεργαστεί με επιτυχία το μήνυμα στο φόρουμ.",
	'groups:forumpost:error' => "Σφάλμα κατά την επεξεργασία του μηνύματος στο φόρουμ.",

	'groups:privategroup' => 'Αυτή η ομάδα είναι κλειστή. Αίτηση εγγραφής.',
	'groups:notitle' => 'Οι ομάδες πρέπει να έχουν τίτλο',
	'groups:cantjoin' => 'Δεν μπορείτε να γίνετε μέλος της ομάδας',
	'groups:cantleave' => 'Δεν ήταν δυνατή η εγκατάλλειψη της ομάδας',
	'groups:removeuser' => 'Διαγραφή από την ομάδα',
	'groups:cantremove' => 'Δεν είναι δυνατή η διαγραφή του χρήστη από την ομάδα',
	'groups:removed' => 'Ο/η %s διαγράφτηκε με επιτυχία από την ομάδα',
	'groups:addedtogroup' => 'Επιτυχής προσθήκη χρήστη στην ομάδα',
	'groups:joinrequestnotmade' => 'Δεν είναι δυνατή η αίτηση εγγραφής στην ομάδα',
	'groups:joinrequestmade' => 'Αίτηση εγγραφής στην ομάδα',
	'groups:joined' => 'Συνδεθήκατε στην ομάδα με επιτυχία!',
	'groups:left' => 'Εγκαταλλείψατε την ομάδα με επιτυχία!',
	'groups:notowner' => 'Λυπούμαστε, δεν είστε ο ιδιοκτήτης αυτής της ομάδας.',
	'groups:notmember' => 'Λυπούμαστε, δεν είστε μέλος αυτής της ομάδας.',
	'groups:alreadymember' => 'Είστε ήδη μέλος αυτής της ομάδας!',
	'groups:userinvited' => 'Ο χρήστης έχει προσκληθεί.',
	'groups:usernotinvited' => 'Ο χρήστης δεν ήταν δυνατόν να προσκληθεί.',
	'groups:useralreadyinvited' => 'Ο χρήστης έχει ήδη προσκληθεί.',
	'groups:invite:subject' => "%s έχετε προσκληθεί να συνδεθείτε στην ομάδα %s!",
	'groups:updated' => "Τελευταία απάντηση από %s %s",
	'groups:started' => "Άρχισε από  %s",
	'groups:joinrequest:remove:check' => 'Είστε σίγουροι για τη διαγραφή του αιτήματος σύνδεσης?',
	'groups:invite:remove:check' => 'Είστε σίγουροι για τη διαγραφή αυτής της πρόσκλησης?',
	'groups:invite:body' => "Γεια σου %s,

Ο/η %s σε προσκάλεσε να συνδεθείς στην ομάδα '%s'. Πατήστε στον παρακάτω σύνδεσμο για προβολή των προσκλήσεων σας:

%s",

	'groups:welcome:subject' => "Καλώς ήλθατε στην ομάδα %s!",
	'groups:welcome:body' => "Γεια σου %s,

Είστε τώρα μέλος της ομάδας '%s'! Πατήστε στον παρακάτω σύνδεσμο για να ξεκινήσετε τη συμμετοχή σας!

%s",

	'groups:request:subject' => "Ο/η %s έχει αιτηθεί να συνδεθεί στην ομάδα %s",
	'groups:request:body' => "Γεια σου %s,

Ο χρήστης %s έχει αιτηθεί να συνδεθεί στην ομάδα '%s'. Πατήστε στον παρακάτω σύνδεσμο για να δείτε το προφίλ του χρήστη:

%s

ή πατήστε στον παρακάτω σύνδεσμο για προβολή των αιτημάτων σύνδεσης στην ομάδα:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => 'Ο/η %s δημιούργησε την ομάδα %s',
	'river:join:group:default' => 'Ο/η %s έγινε μέλος της ομάδας %s',
	'river:create:object:groupforumtopic' => 'Ο/η %s πρόσθεσε μία νέα συζήτηση %s',
	'river:reply:object:groupforumtopic' => 'Ο/η %s απάντησε στη συζήτηση %s',
	'river:reply:view' => 'προβολή απάντησης',

	'groups:nowidgets' => 'Δεν έχουν καθοριστεί εφαρμογές (widgets) για αυτή την ομάδα.',


	'groups:widgets:members:title' => 'Μέλη ομάδας',
	'groups:widgets:members:description' => 'Εμφάνιση μελών ομάδας.',
	'groups:widgets:members:label:displaynum' => 'Εμφάνιση μελών ομάδας.',
	'groups:widgets:members:label:pleaseedit' => 'Παρακαλούμε ρυθμίστε αυτή την εφαρμογή (widget).',

	'groups:widgets:entities:title' => "Αντικείμενα στην ομάδα",
	'groups:widgets:entities:description' => "Προβολή αποθηκευμένων αντικειμένων της ομάδας.",
	'groups:widgets:entities:label:displaynum' => 'Προβολή αντικειμένων της ομάδας.',
	'groups:widgets:entities:label:pleaseedit' => 'Παρακαλούμε ρυθμίστε αυτή την εφαρμογή σας (widget).',

	'groups:forumtopic:edited' => 'Η επεξεργασία του θέματος στο φόρουμ έγινε με επιτυχία.',

	'groups:allowhiddengroups' => 'Θέλετε να επιτρέψετε ιδιωτικές (αόρατες) ομάδες;',
	'groups:whocancreate' => 'Ποιος μπορεί να δημιουργήσει νέες ομάδες?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Η ομάδα και τα περιεχόμενα της διαγράφηκαν',
	'group:notdeleted' => 'Δεν ήταν δυνατή η διαγραφή της ομάδας',

	'group:notfound' => 'Δεν ήταν δυνατή η εύρεση της ομάδας',
	'grouppost:deleted' => 'Η ανάρτηση διαγράφηκε με επιτυχία',
	'grouppost:notdeleted' => 'Δεν ήταν δυνατή η διαγραφή της ανάρτησης',
	'groupstopic:deleted' => 'Το θέμα διαγράφτηκε',
	'groupstopic:notdeleted' => 'Το θέμα δεν διαγράφτηκε',
	'grouptopic:blank' => 'Χωρίς θέμα',
	'grouptopic:notfound' => 'Δεν ήταν δυνατή η εύρεση του θέματος',
	'grouppost:nopost' => 'Κενή ανάρτηση',
	'groups:deletewarning' => "Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την ομάδα; Η ενέργεια αυτή δεν μπορεί να ανατραπεί!",

	'groups:invitekilled' => 'Η πρόσκληση έχει διαγραφεί.',
	'groups:joinrequestkilled' => 'Το αίτημα εγγραφής έχει διαγραφεί.',
	'groups:error:addedtogroup' => "Αδύνατη η προσθήκη του χρήστη %s στην ομάδα",
	'groups:add:alreadymember' => "Ο/η %s είναι ήδη μέλος της ομάδας",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Συζητήσεις Ομάδας',
	'groups:ecml:groupprofile' => 'Προφίλ ομάδας',
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/groups/languages/el.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ομάδες",
	'groups:owned' => "Ομάδες που μου ανήκουν",
	'groups:owned:user' => 'Ομάδες που ανήκουν στο χρήστη %s',
	'groups:yours' => "Οι ομάδες μου",
	'groups:user' => "Ομάδες του χρήστη %s",
	'groups:all' => "Όλες οι ομάδες",
	'groups:add' => "Δημιουργία ομάδας",
	'groups:edit' => "Επεξεργασία ομάδας",
	'groups:delete' => 'Διαγραφή ομάδας',
	'groups:membershiprequests' => 'Διαχείριση αιτημάτων σύνδεσης',
	'groups:membershiprequests:pending' => 'Διαχείριση αιτημάτων σύνδεσης (%s)',
	'groups:invitedmembers' => "Manage invitations",
	'groups:invitations' => 'Προσκλήσεις ομάδας',
	'groups:invitations:pending' => 'Προσκλήσεις ομάδας (%s)',
	
	'relationship:invited' => '%2$s was invited to join %1$s',
	'relationship:membership_request' => '%s requested to join %s',

	'groups:icon' => 'Εικόνα ομάδας (αφήστε κενό για καμία αλλαγή)',
	'groups:name' => 'Όνομα ομάδας',
	'groups:description' => 'Περιγραφή',
	'groups:briefdescription' => 'Σύντομη περιγραφή',
	'groups:interests' => 'Ετικέτες',
	'groups:website' => 'Ιστότοπος',
	'groups:members' => 'Μέλη ομάδας',

	'groups:members_count' => '%s members',

	'groups:members:title' => 'Μέλη ομάδας %s',
	'groups:members:more' => "Προβολή όλων των μελών",
	'groups:membership' => "Δικαιώματα μελών ομάδας",
	'groups:content_access_mode' => "Προσβασιμότητα του περιεχομένου της ομάδας",
	'groups:content_access_mode:warning' => "Προσοχή: Η αλλαγή αυτής της ρύθμισης δεν θα επηρεάσει τα δικαιώματα πρόσβασης στο υφιστάμενο περιεχόμενο της ομάδας.",
	'groups:content_access_mode:unrestricted' => "Χωρίς περιορισμό - Η πρόσβαση εξαρτάται από τις ρυθμίσεις σε επίπεδο περιεχομένου",
	'groups:content_access_mode:membersonly' => "Μόνο για Μέλη  - Μη μέλη δεν μπορούν να έχουν πρόσβαση στο περιεχόμενο της ομάδας",
	'groups:access' => "Δικαιώματα πρόσβασης",
	'groups:owner' => "Ιδιοκτήτης",
	'groups:owner:warning' => "Προσοχή: εάν αλλάξετε την τιμή αυτή, δεν θα είστε πλέον ο ιδιοκτήτης αυτής της ομάδας.",
	'groups:widget:num_display' => 'Αριθμός ομάδων για εμφάνιση',
	'widgets:a_users_groups:name' => 'Συμμετοχή στην ομάδα',
	'widgets:a_users_groups:description' => 'Εμφάνιση στο προφίλ σας των ομάδων που είστε μέλος ',

	'groups:noaccess' => 'Δεν παρέχεται πρόσβαση στην ομάδα',
	'groups:cantcreate' => 'Δεν μπορείτε να δημιουργήσετε ομάδα. Μόνο οι διαχειριστές μπορούν.',
	'groups:cantedit' => 'Δεν μπορείτε να επεξεργαστείτε αυτή την ομάδα',
	'groups:saved' => 'Η ομάδα αποθηκεύτηκε',
	'groups:save_error' => 'Group could not be saved',
	'groups:featured' => 'Προβεβλημένες ομάδες',
	'groups:makeunfeatured' => 'Μη προτεινόμενο',
	'groups:makefeatured' => 'Προβάλλετε το',
	'groups:featuredon' => '%s είναι πλέον προβεβλημένη ομάδα.',
	'groups:unfeatured' => 'Η ομάδα %s έχει διαγραφεί πλέον από τις προβεβλημένες ομάδες.',
	'groups:featured_error' => 'Μη έγκυρη ομάδα.',
	'groups:nofeatured' => 'Μη προβεβλημένες ομάδες',
	'groups:joinrequest' => 'Αίτημα εγγραφής',
	'groups:join' => 'Συμμετοχή στην ομάδα',
	'groups:leave' => 'Εγκατάλλειψη ομάδας',
	'groups:invite' => 'Πρόσκληση φίλων',
	'groups:invite:title' => 'Πρόσκληση φίλων σ\' αυτή την ομάδα',
	'groups:invite:friends:help' => 'Search for a friend by name or username and select the friend from the list',
	'groups:invite:resend' => 'Resend the invitations to already invited users',
	'groups:invite:member' => 'Already a member of this group',
	'groups:invite:invited' => 'Already invited to this group',

	'groups:nofriendsatall' => 'Δεν έχετε φίλους για να προσκαλέσετε',
	'groups:group' => "Ομάδα",
	'groups:search:tags' => "ετικέτα",
	'groups:search:title' => "Αναζήτηση για ομάδες με ετικέτα '%s'",
	'groups:search:none' => "Δεν βρέθηκαν ομάδες",
	'groups:search_in_group' => "Αναζήτηση σ' αυτή την ομάδα",
	'groups:acl' => "Ομάδα: %s",
	'groups:acl:in_context' => 'Μέλη ομάδας',

	'groups:notfound' => "Η ομάδα δεν βρέθηκε",
	
	'groups:requests:none' => 'Δεν υπάρχουν τρέχουσες αιτήσεις συμμετοχής.',

	'groups:invitations:none' => 'Δεν υπάρχουν τρέχουσες προσκλήσεις.',

	'groups:open' => "Ανοικτή ομάδα",
	'groups:closed' => "Κλειστή ομάδα",
	'groups:member' => "μέλη",
	'groups:search' => "Search for groups",

	'groups:more' => 'Περισσότερες ομάδες',
	'groups:none' => 'Δεν υπάρχουν ομάδες',

	/**
	 * Access
	 */
	'groups:access:private' => 'Κλειστό - Οι χρήστες πρέπει να προσκληθούν',
	'groups:access:public' => 'Ανοικτό - Όλοι οι χρήστες μπορούν να συνδεθούν',
	'groups:access:group' => 'Μόνο μέλη της ομάδας',
	'groups:closedgroup' => "Αυτή η ομάδα είναι κλειστή.",
	'groups:closedgroup:request' => 'Για να ζητήσετε τη συμμετοχής σας, κάντε κλικ στο "Αίτημα εγγραφής" στο μενού.',
	'groups:closedgroup:membersonly' => "Η ομάδα αυτή είναι κλειστή και το περιεχόμενό της είναι προσβάσιμο μόνο από τα μέλη.",
	'groups:opengroup:membersonly' => "Το περιεχόμενο της ομάδας της είναι προσβάσιμο μόνο από τα μέλη.",
	'groups:opengroup:membersonly:join' => 'Για να γίνετε μέλος, επιλέξτε "Συμμετοχή στην ομάδα" στο μενού.',
	'groups:visibility' => 'Ποιος μπορεί να δει αυτή την ομάδα?',
	'groups:content_default_access' => 'Default group content access',
	'groups:content_default_access:help' => 'Here you can configure the default access for new content in this group. The group content mode can prevent the selected option from being in effect.',
	'groups:content_default_access:not_configured' => 'No default access configured, leave to the user',

	/**
	 * Group tools
	 */

	'admin:groups' => 'Ομάδες',

	'groups:notitle' => 'Οι ομάδες πρέπει να έχουν τίτλο',
	'groups:cantjoin' => 'Δεν μπορείτε να γίνετε μέλος της ομάδας',
	'groups:cantleave' => 'Δεν ήταν δυνατή η εγκατάλλειψη της ομάδας',
	'groups:removeuser' => 'Διαγραφή από την ομάδα',
	'groups:cantremove' => 'Δεν είναι δυνατή η διαγραφή του χρήστη από την ομάδα',
	'groups:removed' => 'Ο/η %s διαγράφτηκε με επιτυχία από την ομάδα',
	'groups:addedtogroup' => 'Επιτυχής προσθήκη χρήστη στην ομάδα',
	'groups:joinrequestnotmade' => 'Δεν είναι δυνατή η αίτηση εγγραφής στην ομάδα',
	'groups:joinrequestmade' => 'Αίτηση εγγραφής στην ομάδα',
	'groups:joinrequest:exists' => 'You already requested membership for this group',
	'groups:button:joined' => 'Joined',
	'groups:button:owned' => 'Owned',
	'groups:joined' => 'Συνδεθήκατε στην ομάδα με επιτυχία!',
	'groups:left' => 'Εγκαταλλείψατε την ομάδα με επιτυχία!',
	'groups:userinvited' => 'Ο χρήστης έχει προσκληθεί.',
	'groups:usernotinvited' => 'Ο χρήστης δεν ήταν δυνατόν να προσκληθεί.',
	'groups:useralreadyinvited' => 'Ο χρήστης έχει ήδη προσκληθεί.',
	'groups:invite:subject' => "%s έχετε προσκληθεί να συνδεθείτε στην ομάδα %s!",
	'groups:joinrequest:remove:check' => 'Είστε σίγουροι για τη διαγραφή του αιτήματος σύνδεσης?',
	'groups:invite:remove:check' => 'Είστε σίγουροι για τη διαγραφή αυτής της πρόσκλησης?',
	'groups:invite:body' => "Hi %s,

%s invited you to join the '%s' group.

Click below to view your invitations:
%s",

	'groups:welcome:subject' => "Καλώς ήλθατε στην ομάδα %s!",
	'groups:welcome:body' => "Hi %s!

You are now a member of the '%s' group.

Click below to begin posting!
%s",

	'groups:request:subject' => "Ο/η %s έχει αιτηθεί να συνδεθεί στην ομάδα %s",
	'groups:request:body' => "Hi %s,

%s has requested to join the '%s' group.

Click below to view their profile:
%s

or click below to view the group's join requests:
%s",

	'river:group:create' => '%s created the group %s',
	'river:group:join' => '%s joined the group %s',

	'groups:allowhiddengroups' => 'Θέλετε να επιτρέψετε ιδιωτικές (αόρατες) ομάδες;',
	'groups:whocancreate' => 'Ποιος μπορεί να δημιουργήσει νέες ομάδες?',

	/**
	 * Action messages
	 */
	'groups:deleted' => 'Group and group contents deleted',
	'groups:notdeleted' => 'Group could not be deleted',
	'groups:deletewarning' => "Είστε σίγουροι ότι θέλετε να διαγράψετε αυτή την ομάδα; Η ενέργεια αυτή δεν μπορεί να ανατραπεί!",

	'groups:invitekilled' => 'Η πρόσκληση έχει διαγραφεί.',
	'groups:joinrequestkilled' => 'Το αίτημα εγγραφής έχει διαγραφεί.',
	'groups:error:addedtogroup' => "Αδύνατη η προσθήκη του χρήστη %s στην ομάδα",
	'groups:add:alreadymember' => "Ο/η %s είναι ήδη μέλος της ομάδας",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Προφίλ ομάδας',

	/**
	 * Upgrades
	 */
	'groups:upgrade:2016101900:title' => 'Transfer group icons to a new location',
	'groups:upgrade:2016101900:description' => 'New entity icon API stores icons in a predictable location on the filestore
relative to the entity\'s filestore directory. This upgrade will align the group plugin with the requirements of the new API.',
);
